package com.miaxis.pc.controller.question;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.domain.entity.SysRole;
import com.miaxis.common.core.domain.entity.SysUser;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.common.utils.SecurityUtils;
import com.miaxis.score.domain.ScoreInfo;
import com.miaxis.score.dto.ScoreInfoPcDTO;
import com.miaxis.score.service.IScoreInfoService;
import com.miaxis.score.vo.ScoreIStudentInfoPcVo;
import com.miaxis.user.service.IUserInfoService;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

/**
 * 【模拟考成绩】Controller
 *
 * @author miaxis
 * @date 2021-08-23
 */
@RestController
@RequestMapping("score/info")
@Api(tags={"【PC-模拟考成绩】"})
public class PcScoreInfoController extends BaseController {
    @Autowired
    private IScoreInfoService scoreInfoService;


    @Autowired
    private IUserInfoService userInfoService;

//    /**
//     * 查询模拟考成绩列表
//     */
//    @GetMapping("/list")
//    @ApiOperation("查询模拟考成绩列表")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
//            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
//    })
//    public ResponsePageInfo<ScoreInfoPcVo> list(@ModelAttribute ScoreInfoPcDTO scoreInfoPcDTO){
//        startPage();
//        List<ScoreInfoPcVo> list = scoreInfoService.selectScoreInfoPcList(scoreInfoPcDTO);
//        return toResponsePageInfo(list);
//    }


    /**
     * 查询学员列表
     */
    @GetMapping("/studentlist")
    @ApiOperation("查询驾校学员列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<ScoreIStudentInfoPcVo> studentList(@ModelAttribute ScoreInfoPcDTO scoreInfoPcDTO){
        startPage();
        //判断该用户是否拥有amin或者manager角色
        SysUser user = SecurityUtils.getLoginUser().getUser();
        List<SysRole> roles = user.getRoles();
        Boolean hasAdminAuthority = false;
        for (SysRole sysRole : roles){
            if (sysRole.getRoleKey().equals("admin") || sysRole.getRoleKey().equals("manager")){
                hasAdminAuthority =true;
            }
        }
        if (!hasAdminAuthority){
            scoreInfoPcDTO.setSchoolName(user.getNickName());
        }
        List<ScoreIStudentInfoPcVo> list = scoreInfoService.selectStudentList(scoreInfoPcDTO);
        return toResponsePageInfo(list);
    }

    /**
     * 查询学员成绩
     */
    @GetMapping("/studentscore/{userId}")
    @ApiOperation("查询学员成绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<ScoreInfo> studentscore( @PathVariable("userId") Long userId){
        startPage();
        List<ScoreInfo> list = scoreInfoService.list(new QueryWrapper<ScoreInfo>().eq("user_id",userId));
        return toResponsePageInfo(list);
    }





    /**
     * 修改模拟考成绩
     */
    @Log(title = "模拟考成绩", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改模拟考成绩")
    public Response<Integer> edit(@RequestBody ScoreInfo scoreInfo){
        return toResponse(scoreInfoService.updateById(scoreInfo) ? 1 : 0);
    }

    /**
     * 删除模拟考成绩
     */
    @Log(title = "模拟考成绩", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除模拟考成绩")
    public Response<Integer> remove(
            @ApiParam(name = "ids", value = "模拟考成绩ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return toResponse(scoreInfoService.removeByIds(Arrays.asList(ids)) ? 1 : 0);
    }






}
